server_client_20150129_153254

### config1 : test_load_balance

Result | Function execution time | Total execution time
--- | --- | ---
Passed | 3.56660604477 sec | 5.75202679634 sec

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 0.0
latency | 4.46 | 0.76 | 0.34 | 0.41 | 0.44 | 0.63 | 2.36 | 4.04 | 1.12

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 30.96 | 25.47 | 22.56 | 22.90 | 26.93 | 29.35 | 30.16 | 30.80 | 3.88
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.41
server1-perf | latency | mean lt 0.33 | 0.759833333333
server1-perf | qps | mean lt 7.0 | 4.0
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 22.899
client1-perf | latency | mean lt 35.0 | 25.4743333333
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None